@@ -50,9 +50,9 @@ if (!isGeneric("polygons<-"))
 if (!isGeneric("proj4string"))
 	setGeneric("proj4string", function(obj)
 		standardGeneric("proj4string"))
-if (!isGeneric("proj4string<-"))
-	setGeneric("proj4string<-", function(obj, value)
-		standardGeneric("proj4string<-"))
+#if (!isGeneric("proj4string<-"))
+#	setGeneric("proj4string<-", function(obj, value)
+#		standardGeneric("proj4string<-"))
 if (!isGeneric("spplot"))
 	setGeneric("spplot", function(obj, ...)
 		standardGeneric("spplot"))
